django\_readonly\_field package
===============================

Submodules
----------

django\_readonly\_field.apps module
-----------------------------------

.. automodule:: django_readonly_field.apps
   :members:
   :undoc-members:
   :show-inheritance:

django\_readonly\_field.compiler module
---------------------------------------

.. automodule:: django_readonly_field.compiler
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: django_readonly_field
   :members:
   :undoc-members:
   :show-inheritance:
